CCL: norm_params Struct Reference

CCL

Data Fields
norm_params Struct Reference

## Data Fields
double | bin_zmin_
double | bin_zmax_
int | type_
user_pz_info * | user_information
double(* | unnormedfunc )(double, void *)
int * | status

## Field Documentation

## ◆ bin_zmax_

double norm_params::bin_zmax_

## ◆ bin_zmin_

double norm_params::bin_zmin_

## ◆ status

int* norm_params::status

## ◆ type_

int norm_params::type_

## ◆ unnormedfunc

double(* norm_params::unnormedfunc) (double, void *)

## ◆ user_information

user_pz_info* norm_params::user_information

The documentation for this struct was generated from the following file:

- /home/chisarie/Documents/lsst_ccl/CCL/src/ccl_lsst_specs.c